@@ -184,12 +184,20 @@ void QalculateQtSettings::readPreferenceValue(const std::string &svar, const std
 	} else if(!is_workspace && svar == "favourite_function") {
 		favourite_functions_pre.push_back(svalue);
 		favourite_functions_changed = true;
+	} else if(!is_workspace && svar == "recent_function") {
+		recent_functions_pre.push_back(svalue);
 	} else if(!is_workspace && svar == "favourite_unit") {
 		favourite_units_pre.push_back(svalue);
 		favourite_units_changed = true;
+	} else if(!is_workspace && svar == "recent_unit") {
+		recent_units_pre.push_back(svalue);
+	} else if(!is_workspace && svar == "latest_button_unit") {
+		latest_button_unit = svalue;
 	} else if(!is_workspace && svar == "favourite_variable") {
 		favourite_variables_pre.push_back(svalue);
 		favourite_variables_changed = true;
+	} else if(!is_workspace && svar == "recent_variable") {
+		recent_variables_pre.push_back(svalue);
 	} else if(!is_workspace && svar == "keyboard_shortcut") {
 		default_shortcuts = false;
 		char str1[svalue.length()];
@@ -271,8 +279,20 @@ void QalculateQtSettings::readPreferenceValue(const std::string &svar, const std
 				custom_buttons[index].value[bi] = "";
 			}
 		}
+	} else if(!is_workspace && svar == "show_all_units") {
+		show_all_units = v;
+	} else if(!is_workspace && svar == "show_all_functions") {
+		show_all_functions = v;
+	} else if(!is_workspace && svar == "show_all_variables") {
+		show_all_variables = v;
+	} else if(!is_workspace && svar == "use_function_dialog") {
+		use_function_dialog = v;
 	} else if(svar == "keypad_type") {
 		if(v >= 0 && v <= 3) keypad_type = v;
+	} else if(svar == "toolbar_style") {
+		if(v == Qt::ToolButtonIconOnly || v == Qt::ToolButtonTextOnly || v == Qt::ToolButtonTextBesideIcon || v == Qt::ToolButtonTextUnderIcon) toolbar_style = v;
+	} else if(svar == "separate_keypad_menu_buttons") {
+		separate_keypad_menu_buttons = v;
 	} else if(svar == "hide_numpad") {
 		hide_numpad = v;
 	} else if(svar == "show_keypad") {
@@ -845,6 +865,8 @@ void QalculateQtSettings::loadPreferences() {
 	expression_status_delay = 1000;
 	prefixes_default = true;
 	keypad_type = 0;
+	toolbar_style = Qt::ToolButtonIconOnly;
+	separate_keypad_menu_buttons = false;
 	show_keypad = -1;
 	hide_numpad = false;
 	show_bases = -1;
@@ -903,6 +925,11 @@ void QalculateQtSettings::loadPreferences() {
 	favourite_variables_changed = false;
 	favourite_units_changed = false;
 
+	show_all_functions = false;
+	show_all_variables = false;
+	show_all_units = false;
+	use_function_dialog = true;
+
 	FILE *file = NULL;
 	std::string filename = buildPath(getLocalDir(), "qalculate-qt.cfg");
 	file = fopen(filename.c_str(), "r");
@@ -927,7 +954,7 @@ void QalculateQtSettings::loadPreferences() {
 
 	preferences_version[0] = 4;
 	preferences_version[1] = 8;
-	preferences_version[2] = 0;
+	preferences_version[2] = 1;
 
 	if(file) {
 		char line[1000000L];
@@ -980,6 +1007,9 @@ void QalculateQtSettings::loadPreferences() {
 		ADD_SHORTCUT("Ctrl+Enter", SHORTCUT_TYPE_APPROXIMATE, "")
 		ADD_SHORTCUT("Ctrl+Return", SHORTCUT_TYPE_APPROXIMATE, "")
 		ADD_SHORTCUT("Alt+M", SHORTCUT_TYPE_MODE, "")
+		ADD_SHORTCUT("Alt+F", SHORTCUT_TYPE_FUNCTIONS_MENU, "")
+		ADD_SHORTCUT("Alt+U", SHORTCUT_TYPE_UNITS_MENU, "")
+		ADD_SHORTCUT("Alt+V", SHORTCUT_TYPE_VARIABLES_MENU, "")
 		ADD_SHORTCUT("F10", SHORTCUT_TYPE_MENU, "")
 		ADD_SHORTCUT("Ctrl+)", SHORTCUT_TYPE_SMART_PARENTHESES, "")
 		ADD_SHORTCUT("Ctrl+(", SHORTCUT_TYPE_SMART_PARENTHESES, "")
@@ -993,6 +1023,16 @@ void QalculateQtSettings::loadPreferences() {
 		ADD_SHORTCUT("Tab", SHORTCUT_TYPE_COMPLETE, "")
 	} else if(PREFERENCES_VERSION_BEFORE(4, 1, 2)) {
 		ADD_SHORTCUT("Tab", SHORTCUT_TYPE_COMPLETE, "")
+	} else if(PREFERENCES_VERSION_BEFORE(4, 8, 1)) {
+		bool b1 = false, b2 = false, b3 = false;
+		for(size_t i = 0; i < keyboard_shortcuts.size(); i++) {
+			if(keyboard_shortcuts[i]->key == "Alt+F") b1 = true;
+			else if(keyboard_shortcuts[i]->key == "Alt+U") b2 = true;
+			else if(keyboard_shortcuts[i]->key == "Alt+V") b3 = true;
+		}
+		if(!b1) {ADD_SHORTCUT("Alt+F", SHORTCUT_TYPE_FUNCTIONS_MENU, "")}
+		if(!b2) {ADD_SHORTCUT("Alt+U", SHORTCUT_TYPE_UNITS_MENU, "")}
+		if(!b3) {ADD_SHORTCUT("Alt+V", SHORTCUT_TYPE_VARIABLES_MENU, "")}
 	}
 
 	updateMessagePrintOptions();
@@ -1045,6 +1085,10 @@ void QalculateQtSettings::updateFavourites() {
 			if(f) favourite_functions.push_back(f);
 		}
 	}
+	for(size_t i = 0; i < recent_functions_pre.size(); i++) {
+		MathFunction *f = CALCULATOR->getActiveFunction(recent_functions_pre[i]);
+		if(f) recent_functions.push_back(f);
+	}
 	if(favourite_units_pre.empty()) {
 		const char *si_units[] = {"m", "kg_c", "s", "A", "K", "mol", "cd"};
 		for(size_t i = 0; i < 7; i++) {
@@ -1062,6 +1106,11 @@ void QalculateQtSettings::updateFavourites() {
 			if(u) favourite_units.push_back(u);
 		}
 	}
+	for(size_t i = 0; i < recent_units_pre.size(); i++) {
+		Unit *u = CALCULATOR->getActiveUnit(recent_units_pre[i]);
+		if(!u) u = CALCULATOR->getCompositeUnit(recent_units_pre[i]);
+		if(u) recent_units.push_back(u);
+	}
 	if(favourite_variables_pre.empty()) {
 		favourite_variables.push_back(CALCULATOR->getVariableById(VARIABLE_ID_PI));
 		favourite_variables.push_back(CALCULATOR->getVariableById(VARIABLE_ID_E));
@@ -1077,6 +1126,10 @@ void QalculateQtSettings::updateFavourites() {
 			if(v) favourite_variables.push_back(v);
 		}
 	}
+	for(size_t i = 0; i < recent_variables_pre.size(); i++) {
+		Variable *v = CALCULATOR->getActiveVariable(recent_variables_pre[i]);
+		if(v) recent_variables.push_back(v);
+	}
 }
 
 #if defined _WIN32 && (QT_VERSION >= QT_VERSION_CHECK(6, 5, 0))
@@ -1253,6 +1306,8 @@ bool QalculateQtSettings::savePreferences(const char *filename, bool is_workspac
 		fprintf(file, "completion_min2=%i\n", completion_min2);
 		fprintf(file, "completion_delay=%i\n", completion_delay);
 		fprintf(file, "style=%i\n", style);
+		if(toolbar_style != Qt::ToolButtonIconOnly) fprintf(file, "toolbar_style=%i\n", toolbar_style);
+		fprintf(file, "separate_keypad_menu_buttons=%i\n", separate_keypad_menu_buttons);
 		fprintf(file, "palette=%i\n", palette);
 		fprintf(file, "color=%i\n", colorize_result);
 		if(!format_result) fprintf(file, "format=%i\n", format_result);
@@ -1281,6 +1336,10 @@ bool QalculateQtSettings::savePreferences(const char *filename, bool is_workspac
 	}
 	if(!is_workspace) {
 		fprintf(file, "rpn_keys=%i\n", rpn_keys);
+		fprintf(file, "show_all_functions=%i\n", show_all_functions);
+		fprintf(file, "show_all_units=%i\n", show_all_units);
+		fprintf(file, "show_all_variables=%i\n", show_all_variables);
+		fprintf(file, "use_function_dialog=%i\n", use_function_dialog);
 		if(!current_workspace.empty()) fprintf(file, "last_workspace=%s\n", current_workspace.c_str());
 		if(save_workspace >= 0) fprintf(file, "save_workspace=%i\n", save_workspace);
 		for(size_t i = 0; i < recent_workspaces.size(); i++) {
@@ -1314,6 +1373,11 @@ bool QalculateQtSettings::savePreferences(const char *filename, bool is_workspac
 				}
 			}
 		}
+		for(size_t i = 0; i < recent_functions.size(); i++) {
+			if(CALCULATOR->stillHasFunction(recent_functions[i]) && recent_functions[i]->isActive() && recent_functions[i]->category() != CALCULATOR->temporaryCategory()) {
+				fprintf(file, "recent_function=%s\n", recent_functions[i]->referenceName().c_str());
+			}
+		}
 		if(favourite_units_changed) {
 			for(size_t i = 0; i < favourite_units.size(); i++) {
 				if(CALCULATOR->stillHasUnit(favourite_units[i]) && favourite_units[i]->isActive() && favourite_units[i]->category() != CALCULATOR->temporaryCategory()) {
@@ -1321,6 +1385,12 @@ bool QalculateQtSettings::savePreferences(const char *filename, bool is_workspac
 				}
 			}
 		}
+		for(size_t i = 0; i < recent_units.size(); i++) {
+			if(CALCULATOR->stillHasUnit(recent_units[i]) && recent_units[i]->isActive() && recent_units[i]->category() != CALCULATOR->temporaryCategory()) {
+				fprintf(file, "recent_unit=%s\n", recent_units[i]->referenceName().c_str());
+			}
+		}
+		if(!latest_button_unit.empty()) fprintf(file, "latest_button_unit=%s\n", latest_button_unit.c_str());
 		if(favourite_variables_changed) {
 			for(size_t i = 0; i < favourite_variables.size(); i++) {
 				if(CALCULATOR->stillHasVariable(favourite_variables[i]) && favourite_variables[i]->isActive() && favourite_variables[i]->category() != CALCULATOR->temporaryCategory()) {
@@ -1328,6 +1398,11 @@ bool QalculateQtSettings::savePreferences(const char *filename, bool is_workspac
 				}
 			}
 		}
+		for(size_t i = 0; i < recent_variables.size(); i++) {
+			if(CALCULATOR->stillHasVariable(recent_variables[i]) && recent_variables[i]->isActive() && recent_variables[i]->category() != CALCULATOR->temporaryCategory()) {
+				fprintf(file, "recent_variable=%s\n", recent_variables[i]->referenceName().c_str());
+			}
+		}
 		if(default_bits >= 0) fprintf(file, "bit_width=%i\n", default_bits);
 		if(default_signed >= 0) fprintf(file, "signed_integer=%i\n", default_signed);
 		fprintf(file, "spell_out_logical_operators=%i\n", printops.spell_out_logical_operators);
@@ -1921,6 +1996,9 @@ QString QalculateQtSettings::shortcutTypeText(shortcut_type type) {
 		case SHORTCUT_TYPE_CALCULATE_EXPRESSION: {return tr("Calculate expression");}
 		case SHORTCUT_TYPE_EXPRESSION_HISTORY_NEXT: {return tr("Expression history next");}
 		case SHORTCUT_TYPE_EXPRESSION_HISTORY_PREVIOUS: {return tr("Expression history previous");}
+		case SHORTCUT_TYPE_FUNCTIONS_MENU: {return tr("Open functions menu");}
+		case SHORTCUT_TYPE_UNITS_MENU: {return tr("Open units menu");}
+		case SHORTCUT_TYPE_VARIABLES_MENU: {return tr("Open variables menu");}
 	}
 	return "-";
 }
