@@ -157,10 +157,13 @@ typedef enum {
 	SHORTCUT_TYPE_PRECISION,
 	SHORTCUT_TYPE_MIN_DECIMALS,
 	SHORTCUT_TYPE_MAX_DECIMALS,
-	SHORTCUT_TYPE_MINMAX_DECIMALS
+	SHORTCUT_TYPE_MINMAX_DECIMALS,
+	SHORTCUT_TYPE_FUNCTIONS_MENU,
+	SHORTCUT_TYPE_UNITS_MENU,
+	SHORTCUT_TYPE_VARIABLES_MENU
 } shortcut_type;
 
-#define LAST_SHORTCUT_TYPE SHORTCUT_TYPE_MINMAX_DECIMALS
+#define LAST_SHORTCUT_TYPE SHORTCUT_TYPE_VARIABLES_MENU
 
 #define SHORTCUT_REQUIRES_VALUE(x) (x == SHORTCUT_TYPE_FUNCTION || x == SHORTCUT_TYPE_FUNCTION_WITH_DIALOG || x == SHORTCUT_TYPE_UNIT || x == SHORTCUT_TYPE_VARIABLE || x == SHORTCUT_TYPE_TEXT || x == SHORTCUT_TYPE_OPERATOR || x == SHORTCUT_TYPE_CONVERT_TO || x == SHORTCUT_TYPE_TO_NUMBER_BASE || x == SHORTCUT_TYPE_INPUT_BASE || x == SHORTCUT_TYPE_OUTPUT_BASE || x == SHORTCUT_TYPE_PRECISION || x == SHORTCUT_TYPE_MAX_DECIMALS || x == SHORTCUT_TYPE_MIN_DECIMALS || x == SHORTCUT_TYPE_MINMAX_DECIMALS)
 
@@ -247,6 +250,8 @@ class QalculateQtSettings : QObject {
 		bool autocopy_result;
 		int default_signed = -1, default_bits = -1;
 		int keypad_type;
+		bool separate_keypad_menu_buttons;
+		int toolbar_style;
 		int show_keypad;
 		int show_bases;
 		bool hide_numpad;
@@ -295,17 +300,19 @@ class QalculateQtSettings : QObject {
 		std::vector<std::vector<bool> > v_delresult;
 		std::vector<std::vector<int> > v_exact;
 		std::vector<std::vector<size_t> > v_value;
-		std::vector<MathFunction*> favourite_functions;
-		std::vector<Variable*> favourite_variables;
-		std::vector<Unit*> favourite_units;
-		std::vector<std::string> favourite_functions_pre;
-		std::vector<std::string> favourite_variables_pre;
-		std::vector<std::string> favourite_units_pre;
+		std::vector<MathFunction*> favourite_functions, recent_functions;
+		std::vector<Variable*> favourite_variables, recent_variables;
+		std::vector<Unit*> favourite_units, recent_units;
+		std::string latest_button_unit;
+		std::vector<std::string> favourite_functions_pre, recent_functions_pre;
+		std::vector<std::string> favourite_variables_pre, recent_variables_pre;
+		std::vector<std::string> favourite_units_pre, recent_units_pre;
 		bool default_shortcuts;
 		std::vector<keyboard_shortcut*> keyboard_shortcuts;
 		int custom_button_columns, custom_button_rows;
 		std::vector<custom_button> custom_buttons;
 		bool favourite_functions_changed, favourite_variables_changed, favourite_units_changed;
+		bool show_all_functions, show_all_variables, show_all_units, use_function_dialog;
 
 };
 
