@@ -17,6 +17,7 @@
 #include <QSpinBox>
 #include <QTranslator>
 #include <QDockWidget>
+#include <QToolButton>
 #include <libqalculate/qalculate.h>
 
 class QLocalSocket;
@@ -30,7 +31,6 @@ class KeypadWidget;
 class QAction;
 class QToolBar;
 class QTextEdit;
-class QToolButton;
 class QTimer;
 class PreferencesDialog;
 class FunctionsDialog;
@@ -102,13 +102,15 @@ class QalculateWindow : public QMainWindow {
 		QLabel *binEdit, *octEdit, *decEdit, *hexEdit;
 		QLabel *binLabel, *octLabel, *decLabel, *hexLabel;
 		QToolBar *tb;
-		QToolButton *menuAction_t, *modeAction_t, *keypadAction_t;
-		QAction *toAction, *storeAction, *functionsAction_t, *unitsAction_t, *plotAction_t, *basesAction, *customOutputBaseAction, *customInputBaseAction, *newVariableAction, *newFunctionAction, *variablesAction, *functionsAction, *unitsAction, *datasetsAction, *plotAction, *fpAction, *calendarsAction, *percentageAction, *periodicTableAction, *exratesAction, *quitAction, *helpAction, *keypadAction, *rpnAction, *chainAction, *gKeypadAction, *pKeypadAction, *xKeypadAction, *cKeypadAction, *hideNumpadAction, *resetKeypadPositionAction, *radAction, *degAction, *graAction, *normalAction, *sciAction, *engAction, *simpleAction;
-		QMenu *variablesMenu, *functionsMenu, *unitsMenu, *angleMenu;
+		QToolButton *menuAction_t, *modeAction_t, *keypadAction_t, *storeAction_t, *functionsAction_t, *unitsAction_t;
+		QMenu *tmenu;
+		QAction *toAction, *plotAction_t, *basesAction, *customOutputBaseAction, *customInputBaseAction, *newVariableAction, *newFunctionAction, *variablesAction, *functionsAction, *unitsAction, *datasetsAction, *plotAction, *fpAction, *calendarsAction, *percentageAction, *periodicTableAction, *exratesAction, *quitAction, *helpAction, *keypadAction, *rpnAction, *chainAction, *gKeypadAction, *pKeypadAction, *xKeypadAction, *cKeypadAction, *hideNumpadAction, *resetKeypadPositionAction, *radAction, *degAction, *graAction, *normalAction, *sciAction, *engAction, *simpleAction;
+		QMenu *recentVariablesMenu, *favouriteVariablesMenu, *variablesMenu, *functionsMenu, *recentFunctionsMenu, *favouriteFunctionsMenu, *unitsMenu, *recentUnitsMenu, *favouriteUnitsMenu, *angleMenu;
 		QAction *assumptionTypeActions[5], *assumptionSignActions[6];
 		QMenu *recentWSMenu;
 		QAction *recentWSSeparator, *openWSAction, *defaultWSAction, *saveWSAction, *saveWSAsAction;
-		QList<QAction*> recentWSAction;
+		QAction *firstFunctionsMenuOptionAction, *firstVariablesMenuOptionAction, *firstUnitsMenuOptionAction;
+		QList<QAction*> recentWSAction, recentVariableActions, favouriteVariableActions, recentFunctionActions, favouriteFunctionActions, recentUnitActions, favouriteUnitActions;
 		QSpinBox *customOutputBaseEdit, *customInputBaseEdit;
 		QTimer *ecTimer, *rfTimer;
 		QFont saved_app_font;
@@ -151,6 +153,7 @@ class QalculateWindow : public QMainWindow {
 		void onFunctionClicked(MathFunction*);
 		void onVariableClicked(Variable*);
 		void onUnitClicked(Unit*);
+		void onPrefixClicked(Prefix*);
 		void onClearClicked();
 		void onDelClicked();
 		void onEqualsClicked();
@@ -170,10 +173,12 @@ class QalculateWindow : public QMainWindow {
 		void onBaseClicked(int, bool);
 		void onFactorizeClicked();
 		void onExpandClicked();
+		void onExpandPartialFractionsClicked();
 		void onToActivated(bool = true);
 		void onStoreActivated();
 		void keypadTypeActivated();
 		void hideNumpad(bool);
+		void showSeparateKeypadMenuButtons(bool);
 		void resetKeypadPosition();
 		void onKeypadVisibilityChanged(bool);
 		void onBasesActivated(bool);
@@ -241,11 +246,26 @@ class QalculateWindow : public QMainWindow {
 		void onExpressionStatusModeChanged();
 		void functionActivated();
 		void unitActivated();
+		void prefixActivated();
 		void variableActivated();
 		void updateAngleUnitsMenu();
 		void updateFunctionsMenu();
+		void useFunctionDialog(bool);
+		void showAllFunctions(bool);
+		void updateFavouriteFunctions();
+		void updateRecentFunctions();
+		void addToRecentFunctions(MathFunction*);
 		void updateUnitsMenu();
+		void addCurrencyFlagsToMenu();
+		void showAllUnits(bool);
+		void updateFavouriteUnits();
+		void updateRecentUnits();
+		void addToRecentUnits(Unit*);
 		void updateVariablesMenu();
+		void showAllVariables(bool);
+		void updateFavouriteVariables();
+		void updateRecentVariables();
+		void addToRecentVariables(Variable*);
 		void shortcutActivated();
 		void shortcutClicked(int, const QString&);
 		void keyboardShortcutAdded(keyboard_shortcut *ks);
@@ -265,7 +285,11 @@ class QalculateWindow : public QMainWindow {
 		void openDefaultWorkspace();
 		void openRecentWorkspace();
 		void onColorSchemeChanged();
-
+		void showToolbarContextMenu(const QPoint&);
+		void setToolbarStyle();
+		void showKeypadContextMenu(const QPoint&);
+		void updateKeypadTitle();
+		void keypadPreferencesChanged();
 
 	public slots:
 
@@ -358,6 +382,7 @@ class QalculateDockWidget : public QDockWidget {
 	public:
 
 		QalculateDockWidget(const QString &name, QWidget *parent, ExpressionEdit *editwidget);
+		QalculateDockWidget(QWidget *parent, ExpressionEdit *editwidget);
 		virtual ~QalculateDockWidget();
 
 	protected:
@@ -373,5 +398,28 @@ class QalculateDockWidget : public QDockWidget {
 
 };
 
+class QalculateToolButton : public QToolButton {
+
+	Q_OBJECT
+
+	public:
+
+		QalculateToolButton(QWidget *parent = NULL);
+		~QalculateToolButton();
+
+	protected:
+
+		QTimer *longPressTimer;
+		bool b_longpress;
+
+		void mouseReleaseEvent(QMouseEvent*) override;
+		void mousePressEvent(QMouseEvent*) override;
+
+	protected slots:
+
+		void longPressTimeout();
+
+};
+
 #endif //QALCULATE_WINDOW_H
 
